AccessListInspector

Struct AccessListInspector 

pub struct AccessListInspector { /* private fields */ }
An [Inspector] that collects touched accounts and storage slots.

This can be used to construct an AccessList for a transaction via eth_createAccessList

Implementations

Source

impl AccessListInspector

pub fn new(access_list: AccessList, excluded: HashSet<Address>) -> Self

Creates a new AccessListInspector with the given excluded addresses.

pub fn excluded(&self) -> &HashSet<Address>

Returns the excluded addresses.

pub fn touched_slots(&self) -> &HashMap<Address, BTreeSet<H256>>

Returns a reference to the map of addresses and their corresponding touched storage slots.

pub fn into_touched_slots(self) -> HashMap<Address, BTreeSet<H256>>

Consumes the inspector and returns the map of addresses and their corresponding touched storage slots.

pub fn into_access_list(self) -> AccessList

Returns list of addresses and storage keys used by the transaction. It gives you the list of addresses and storage keys that were touched during execution.

pub fn access_list(&self) -> AccessList

Returns list of addresses and storage keys used by the transaction. It gives you the list of addresses and storage keys that were touched during execution.

pub fn collcect_excluded_addresses(&mut self, item: Address)