pub struct AccessListInspector { /* private fields */ }Expand description
An [Inspector] that collects touched accounts and storage slots.
This can be used to construct an AccessList for a transaction via
eth_createAccessList
Implementations
Sourceimpl AccessListInspector
impl AccessListInspector
Sourcepub fn new(access_list: AccessList, excluded: HashSet<Address>) -> Self
pub fn new(access_list: AccessList, excluded: HashSet<Address>) -> Self
Creates a new AccessListInspector with the given excluded addresses.
Sourcepub fn touched_slots(&self) -> &HashMap<Address, BTreeSet<H256>>
pub fn touched_slots(&self) -> &HashMap<Address, BTreeSet<H256>>
Returns a reference to the map of addresses and their corresponding touched storage slots.
Sourcepub fn into_touched_slots(self) -> HashMap<Address, BTreeSet<H256>>
pub fn into_touched_slots(self) -> HashMap<Address, BTreeSet<H256>>
Consumes the inspector and returns the map of addresses and their corresponding touched storage slots.
Sourcepub fn into_access_list(self) -> AccessList
pub fn into_access_list(self) -> AccessList
Returns list of addresses and storage keys used by the transaction. It gives you the list of addresses and storage keys that were touched during execution.
Sourcepub fn access_list(&self) -> AccessList
pub fn access_list(&self) -> AccessList
Returns list of addresses and storage keys used by the transaction. It gives you the list of addresses and storage keys that were touched during execution.
pub fn collcect_excluded_addresses(&mut self, item: Address)